@@ -22,12 +22,12 @@ class KBlocksAnimFade : public QObject
 
 public:
     KBlocksAnimFade(const QList<SvgItemInterface *> &items, int duration, QTimeLine::Direction direction);
-    ~KBlocksAnimFade();
+    ~KBlocksAnimFade() override;
 
-signals:
+Q_SIGNALS:
     void animationFinished();
 
-private slots:
+private Q_SLOTS:
     void valueChanged(qreal value);
     void endAnimation();
 
